from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HostVehicleState2807(_message.Message):
    __slots__ = ["header", "ros2_header", "ibeo_header", "timestamp", "distance_x", "distance_y", "course_angle", "longitudinal_velocity", "yaw_rate", "steering_wheel_angle", "cross_acceleration", "front_wheel_angle", "vehicle_width", "vehicle_front_to_front_axle", "rear_axle_to_front_axle", "rear_axle_to_vehicle_rear", "steer_ratio_poly_0", "steer_ratio_poly_1", "steer_ratio_poly_2", "steer_ratio_poly_3", "longitudinal_acceleration"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_X_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_Y_FIELD_NUMBER: _ClassVar[int]
    COURSE_ANGLE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    STEERING_WHEEL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    CROSS_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    FRONT_WHEEL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_FRONT_TO_FRONT_AXLE_FIELD_NUMBER: _ClassVar[int]
    REAR_AXLE_TO_FRONT_AXLE_FIELD_NUMBER: _ClassVar[int]
    REAR_AXLE_TO_VEHICLE_REAR_FIELD_NUMBER: _ClassVar[int]
    STEER_RATIO_POLY_0_FIELD_NUMBER: _ClassVar[int]
    STEER_RATIO_POLY_1_FIELD_NUMBER: _ClassVar[int]
    STEER_RATIO_POLY_2_FIELD_NUMBER: _ClassVar[int]
    STEER_RATIO_POLY_3_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    timestamp: _time_pb2.Time
    distance_x: int
    distance_y: int
    course_angle: float
    longitudinal_velocity: float
    yaw_rate: float
    steering_wheel_angle: float
    cross_acceleration: float
    front_wheel_angle: float
    vehicle_width: float
    vehicle_front_to_front_axle: float
    rear_axle_to_front_axle: float
    rear_axle_to_vehicle_rear: float
    steer_ratio_poly_0: float
    steer_ratio_poly_1: float
    steer_ratio_poly_2: float
    steer_ratio_poly_3: float
    longitudinal_acceleration: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., distance_x: _Optional[int] = ..., distance_y: _Optional[int] = ..., course_angle: _Optional[float] = ..., longitudinal_velocity: _Optional[float] = ..., yaw_rate: _Optional[float] = ..., steering_wheel_angle: _Optional[float] = ..., cross_acceleration: _Optional[float] = ..., front_wheel_angle: _Optional[float] = ..., vehicle_width: _Optional[float] = ..., vehicle_front_to_front_axle: _Optional[float] = ..., rear_axle_to_front_axle: _Optional[float] = ..., rear_axle_to_vehicle_rear: _Optional[float] = ..., steer_ratio_poly_0: _Optional[float] = ..., steer_ratio_poly_1: _Optional[float] = ..., steer_ratio_poly_2: _Optional[float] = ..., steer_ratio_poly_3: _Optional[float] = ..., longitudinal_acceleration: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\"\x84\x01\n\tContainer\x12\x10\n\x08state_id\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\x12\x10\n\x08outcomes\x18\x04 \x03(\t\x12\x13\n\x0btransitions\x18\x05 \x03(\t\x12\x0c\n\x04type\x18\x06 \x01(\x05\x12\x10\n\x08\x61utonomy\x18\x07 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.container_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONTAINER']._serialized_start=107
  _globals['_CONTAINER']._serialized_end=239
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FieldType(_message.Message):
    __slots__ = ["type_id", "capacity", "string_capacity", "nested_type_name"]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    CAPACITY_FIELD_NUMBER: _ClassVar[int]
    STRING_CAPACITY_FIELD_NUMBER: _ClassVar[int]
    NESTED_TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    type_id: int
    capacity: int
    string_capacity: int
    nested_type_name: str
    def __init__(self, type_id: _Optional[int] = ..., capacity: _Optional[int] = ..., string_capacity: _Optional[int] = ..., nested_type_name: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceNodeRequest(_message.Message):
    __slots__ = ["service"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    service: str
    def __init__(self, service: _Optional[str] = ...) -> None: ...

class ServiceNodeResponse(_message.Message):
    __slots__ = ["node"]
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: str
    def __init__(self, node: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HardwareInterface(_message.Message):
    __slots__ = ["name", "is_available", "is_claimed"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IS_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    IS_CLAIMED_FIELD_NUMBER: _ClassVar[int]
    name: str
    is_available: bool
    is_claimed: bool
    def __init__(self, name: _Optional[str] = ..., is_available: bool = ..., is_claimed: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BlockadeStatus(_message.Message):
    __slots__ = ["participant", "reservation", "any_ready", "last_ready", "last_reached", "assignment_begin", "assignment_end"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    RESERVATION_FIELD_NUMBER: _ClassVar[int]
    ANY_READY_FIELD_NUMBER: _ClassVar[int]
    LAST_READY_FIELD_NUMBER: _ClassVar[int]
    LAST_REACHED_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_BEGIN_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_END_FIELD_NUMBER: _ClassVar[int]
    participant: int
    reservation: int
    any_ready: bool
    last_ready: int
    last_reached: int
    assignment_begin: int
    assignment_end: int
    def __init__(self, participant: _Optional[int] = ..., reservation: _Optional[int] = ..., any_ready: bool = ..., last_ready: _Optional[int] = ..., last_reached: _Optional[int] = ..., assignment_begin: _Optional[int] = ..., assignment_end: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_scheduler_msgs/srv/list_trigger_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_scheduler_msgs.msg import trigger_state_pb2 as make87__messages__ros2_dot_humble_dot_rmf__scheduler__msgs_dot_msg_dot_trigger__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/rmf_scheduler_msgs/srv/list_trigger_states.proto\x12\x32make87_messages_ros2.humble.rmf_scheduler_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/rmf_scheduler_msgs/msg/trigger_state.proto\"`\n\x18ListTriggerStatesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x16\n\x0emodified_after\x18\x02 \x01(\x03\"\xbf\x01\n\x19ListTriggerStatesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\x12R\n\x08triggers\x18\x04 \x03(\x0b\x32@.make87_messages_ros2.humble.rmf_scheduler_msgs.msg.TriggerStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_scheduler_msgs.srv.list_trigger_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTTRIGGERSTATESREQUEST']._serialized_start=239
  _globals['_LISTTRIGGERSTATESREQUEST']._serialized_end=335
  _globals['_LISTTRIGGERSTATESRESPONSE']._serialized_start=338
  _globals['_LISTTRIGGERSTATESRESPONSE']._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/data_tamer_msgs/msg/schemas.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.data_tamer_msgs.msg import schema_pb2 as make87__messages__ros2_dot_rolling_dot_data__tamer__msgs_dot_msg_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/data_tamer_msgs/msg/schemas.proto\x12\x30make87_messages_ros2.rolling.data_tamer_msgs.msg\x1a=make87_messages_ros2/rolling/data_tamer_msgs/msg/schema.proto\"T\n\x07Schemas\x12I\n\x07schemas\x18\x01 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.data_tamer_msgs.msg.Schemab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.data_tamer_msgs.msg.schemas_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEMAS']._serialized_start=179
  _globals['_SCHEMAS']._serialized_end=263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/service_request_details.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rosapi_msgs.msg import type_def_pb2 as make87__messages__ros2_dot_rolling_dot_rosapi__msgs_dot_msg_dot_type__def__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rosapi_msgs/srv/service_request_details.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\x1a;make87_messages_ros2/rolling/rosapi_msgs/msg/type_def.proto\",\n\x1cServiceRequestDetailsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"h\n\x1dServiceRequestDetailsResponse\x12G\n\x08typedefs\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.rosapi_msgs.msg.TypeDefb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.service_request_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVICEREQUESTDETAILSREQUEST']._serialized_start=185
  _globals['_SERVICEREQUESTDETAILSREQUEST']._serialized_end=229
  _globals['_SERVICEREQUESTDETAILSRESPONSE']._serialized_start=231
  _globals['_SERVICEREQUESTDETAILSRESPONSE']._serialized_end=335
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import participant_description_pb2 as _participant_description_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RegisterParticipantRequest(_message.Message):
    __slots__ = ["description"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    description: _participant_description_pb2.ParticipantDescription
    def __init__(self, description: _Optional[_Union[_participant_description_pb2.ParticipantDescription, _Mapping]] = ...) -> None: ...

class RegisterParticipantResponse(_message.Message):
    __slots__ = ["participant_id", "last_itinerary_version", "last_plan_id", "next_storage_base", "error"]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_ITINERARY_VERSION_FIELD_NUMBER: _ClassVar[int]
    LAST_PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    NEXT_STORAGE_BASE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    participant_id: int
    last_itinerary_version: int
    last_plan_id: int
    next_storage_base: int
    error: str
    def __init__(self, participant_id: _Optional[int] = ..., last_itinerary_version: _Optional[int] = ..., last_plan_id: _Optional[int] = ..., next_storage_base: _Optional[int] = ..., error: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.marti_nav_msgs.msg import route_point_pb2 as _route_point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UpdateRouteMetadataRequest(_message.Message):
    __slots__ = ["header", "route_guid", "metadata_points"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROUTE_GUID_FIELD_NUMBER: _ClassVar[int]
    METADATA_POINTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    route_guid: str
    metadata_points: _containers.RepeatedCompositeFieldContainer[_route_point_pb2.RoutePoint]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., route_guid: _Optional[str] = ..., metadata_points: _Optional[_Iterable[_Union[_route_point_pb2.RoutePoint, _Mapping]]] = ...) -> None: ...

class UpdateRouteMetadataResponse(_message.Message):
    __slots__ = ["header", "success", "message"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResetCmd(_message.Message):
    __slots__ = ["header", "ros2_header", "confirm", "reset_type", "reset_user_rpt_id", "reset_user_cmd_id_1", "reset_user_cmd_id_2", "reset_user_cmd_id_3", "reset_user_cmd_id_4", "disable_user_rpt_id", "reenable_default_cmd_id"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_FIELD_NUMBER: _ClassVar[int]
    RESET_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESET_USER_RPT_ID_FIELD_NUMBER: _ClassVar[int]
    RESET_USER_CMD_ID_1_FIELD_NUMBER: _ClassVar[int]
    RESET_USER_CMD_ID_2_FIELD_NUMBER: _ClassVar[int]
    RESET_USER_CMD_ID_3_FIELD_NUMBER: _ClassVar[int]
    RESET_USER_CMD_ID_4_FIELD_NUMBER: _ClassVar[int]
    DISABLE_USER_RPT_ID_FIELD_NUMBER: _ClassVar[int]
    REENABLE_DEFAULT_CMD_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    confirm: bool
    reset_type: int
    reset_user_rpt_id: bool
    reset_user_cmd_id_1: bool
    reset_user_cmd_id_2: bool
    reset_user_cmd_id_3: bool
    reset_user_cmd_id_4: bool
    disable_user_rpt_id: bool
    reenable_default_cmd_id: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., confirm: bool = ..., reset_type: _Optional[int] = ..., reset_user_rpt_id: bool = ..., reset_user_cmd_id_1: bool = ..., reset_user_cmd_id_2: bool = ..., reset_user_cmd_id_3: bool = ..., reset_user_cmd_id_4: bool = ..., disable_user_rpt_id: bool = ..., reenable_default_cmd_id: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_status_msgs/msg/chrony_tracking_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/marti_status_msgs/msg/chrony_tracking_status.proto\x12\x32make87_messages_ros2.rolling.marti_status_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe1\x02\n\x14\x43hronyTrackingStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0f\n\x07stratum\x18\x03 \x01(\x05\x12\x1a\n\x12system_time_offset\x18\x04 \x01(\x01\x12\x13\n\x0blast_offset\x18\x05 \x01(\x01\x12\x12\n\nrms_offset\x18\x06 \x01(\x01\x12\x18\n\x10\x66requency_offset\x18\x07 \x01(\x02\x12\x1a\n\x12residual_frequency\x18\x08 \x01(\x02\x12\x0c\n\x04skew\x18\t \x01(\x02\x12\x12\n\nroot_delay\x18\n \x01(\x01\x12\x17\n\x0froot_dispersion\x18\x0b \x01(\x01\x12\x17\n\x0fupdate_interval\x18\x0c \x01(\x02\x12\x13\n\x0bleap_status\x18\r \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_status_msgs.msg.chrony_tracking_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHRONYTRACKINGSTATUS']._serialized_start=192
  _globals['_CHRONYTRACKINGSTATUS']._serialized_end=545
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.pendulum_msgs.msg import joint_command_pb2 as _joint_command_pb2
from make87_messages_ros2.rolling.pendulum_msgs.msg import joint_state_pb2 as _joint_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RttestResults(_message.Message):
    __slots__ = ["stamp", "command", "state", "cur_latency", "mean_latency", "min_latency", "max_latency", "minor_pagefaults", "major_pagefaults"]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    CUR_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MEAN_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MIN_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MAX_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MINOR_PAGEFAULTS_FIELD_NUMBER: _ClassVar[int]
    MAJOR_PAGEFAULTS_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    command: _joint_command_pb2.JointCommand
    state: _joint_state_pb2.JointState
    cur_latency: int
    mean_latency: float
    min_latency: int
    max_latency: int
    minor_pagefaults: int
    major_pagefaults: int
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., command: _Optional[_Union[_joint_command_pb2.JointCommand, _Mapping]] = ..., state: _Optional[_Union[_joint_state_pb2.JointState, _Mapping]] = ..., cur_latency: _Optional[int] = ..., mean_latency: _Optional[float] = ..., min_latency: _Optional[int] = ..., max_latency: _Optional[int] = ..., minor_pagefaults: _Optional[int] = ..., major_pagefaults: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sick_safevisionary_interfaces.msg import roi_pb2 as make87__messages__ros2_dot_humble_dot_sick__safevisionary__interfaces_dot_msg_dot_roi__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi_array.proto\x12=make87_messages_ros2.humble.sick_safevisionary_interfaces.msg\x1a!make87_messages/core/header.proto\x1aGmake87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd1\x01\n\x08ROIArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x04rois\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.humble.sick_safevisionary_interfaces.msg.ROIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safevisionary_interfaces.msg.roi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROIARRAY']._serialized_start=308
  _globals['_ROIARRAY']._serialized_end=517
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LIDoutputstateSrvRequest(_message.Message):
    __slots__ = ["active"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    active: bool
    def __init__(self, active: bool = ...) -> None: ...

class LIDoutputstateSrvResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.rmf_door_msgs.msg import door_mode_pb2 as _door_mode_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DoorRequest(_message.Message):
    __slots__ = ["request_time", "requester_id", "door_name", "requested_mode"]
    REQUEST_TIME_FIELD_NUMBER: _ClassVar[int]
    REQUESTER_ID_FIELD_NUMBER: _ClassVar[int]
    DOOR_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUESTED_MODE_FIELD_NUMBER: _ClassVar[int]
    request_time: _time_pb2.Time
    requester_id: str
    door_name: str
    requested_mode: _door_mode_pb2.DoorMode
    def __init__(self, request_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., requester_id: _Optional[str] = ..., door_name: _Optional[str] = ..., requested_mode: _Optional[_Union[_door_mode_pb2.DoorMode, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetParamNamesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetParamNamesResponse(_message.Message):
    __slots__ = ["names"]
    NAMES_FIELD_NUMBER: _ClassVar[int]
    names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, names: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import spherical_pb2 as _spherical_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ball(_message.Message):
    __slots__ = ["center"]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    center: _spherical_pb2.Spherical
    def __init__(self, center: _Optional[_Union[_spherical_pb2.Spherical, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/srv/update_route_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_point_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__nav__msgs_dot_msg_dot_route__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/marti_nav_msgs/srv/update_route_metadata.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.srv\x1a?make87_messages_ros2/jazzy/marti_nav_msgs/msg/route_point.proto\"\x84\x01\n\x1aUpdateRouteMetadataRequest\x12\x12\n\nroute_guid\x18\x01 \x01(\t\x12R\n\x0fmetadata_points\x18\x02 \x03(\x0b\x32\x39.make87_messages_ros2.jazzy.marti_nav_msgs.msg.RoutePoint\"?\n\x1bUpdateRouteMetadataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.srv.update_route_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UPDATEROUTEMETADATAREQUEST']._serialized_start=190
  _globals['_UPDATEROUTEMETADATAREQUEST']._serialized_end=322
  _globals['_UPDATEROUTEMETADATARESPONSE']._serialized_start=324
  _globals['_UPDATEROUTEMETADATARESPONSE']._serialized_end=387
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRobotStateFromWarehouseRequest(_message.Message):
    __slots__ = ["name", "robot"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FIELD_NUMBER: _ClassVar[int]
    name: str
    robot: str
    def __init__(self, name: _Optional[str] = ..., robot: _Optional[str] = ...) -> None: ...

class GetRobotStateFromWarehouseResponse(_message.Message):
    __slots__ = ["state"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _robot_state_pb2.RobotState
    def __init__(self, state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mapviz_interfaces/srv/add_mapviz_display.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marti_common_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_marti__common__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/mapviz_interfaces/srv/add_mapviz_display.proto\x12\x32make87_messages_ros2.rolling.mapviz_interfaces.srv\x1a\x42make87_messages_ros2/rolling/marti_common_msgs/msg/key_value.proto\"\xac\x01\n\x17\x41\x64\x64MapvizDisplayRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ndraw_order\x18\x03 \x01(\x05\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12P\n\nproperties\x18\x05 \x03(\x0b\x32<.make87_messages_ros2.rolling.marti_common_msgs.msg.KeyValue\"<\n\x18\x41\x64\x64MapvizDisplayResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mapviz_interfaces.srv.add_mapviz_display_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_start=200
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_end=372
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_start=374
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_end=434
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavSVINFOSV(_message.Message):
    __slots__ = ["header", "chn", "svid", "flags", "quality", "cno", "elev", "azim", "pr_res"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CHN_FIELD_NUMBER: _ClassVar[int]
    SVID_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    CNO_FIELD_NUMBER: _ClassVar[int]
    ELEV_FIELD_NUMBER: _ClassVar[int]
    AZIM_FIELD_NUMBER: _ClassVar[int]
    PR_RES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    chn: int
    svid: int
    flags: int
    quality: int
    cno: int
    elev: int
    azim: int
    pr_res: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., chn: _Optional[int] = ..., svid: _Optional[int] = ..., flags: _Optional[int] = ..., quality: _Optional[int] = ..., cno: _Optional[int] = ..., elev: _Optional[int] = ..., azim: _Optional[int] = ..., pr_res: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/msg/tool_data_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/ur_msgs/msg/tool_data_msg.proto\x12(make87_messages_ros2.rolling.ur_msgs.msg\"\xef\x01\n\x0bToolDataMsg\x12\x1b\n\x13\x61nalog_input_range2\x18\x01 \x01(\x05\x12\x1b\n\x13\x61nalog_input_range3\x18\x02 \x01(\x05\x12\x15\n\ranalog_input2\x18\x03 \x01(\x01\x12\x15\n\ranalog_input3\x18\x04 \x01(\x01\x12\x18\n\x10tool_voltage_48v\x18\x05 \x01(\x02\x12\x1b\n\x13tool_output_voltage\x18\x06 \x01(\r\x12\x14\n\x0ctool_current\x18\x07 \x01(\x02\x12\x18\n\x10tool_temperature\x18\x08 \x01(\x02\x12\x11\n\ttool_mode\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.msg.tool_data_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOOLDATAMSG']._serialized_start=107
  _globals['_TOOLDATAMSG']._serialized_end=346
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceDetails(_message.Message):
    __slots__ = ["service_name", "service_type"]
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    service_name: str
    service_type: str
    def __init__(self, service_name: _Optional[str] = ..., service_type: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleStateMsg3(_message.Message):
    __slots__ = ["header", "yaw_rate_reference_valid", "yaw_rate_reference", "can_veh_long_accel_qf", "can_veh_long_accel"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_REFERENCE_VALID_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    CAN_VEH_LONG_ACCEL_QF_FIELD_NUMBER: _ClassVar[int]
    CAN_VEH_LONG_ACCEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    yaw_rate_reference_valid: bool
    yaw_rate_reference: float
    can_veh_long_accel_qf: int
    can_veh_long_accel: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., yaw_rate_reference_valid: bool = ..., yaw_rate_reference: _Optional[float] = ..., can_veh_long_accel_qf: _Optional[int] = ..., can_veh_long_accel: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_geometry_msgs/msg/line_segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/tuw_geometry_msgs/msg/line_segment.proto\x12\x31make87_messages_ros2.humble.tuw_geometry_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\"\xcb\x01\n\x0bLineSegment\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12@\n\x02p0\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12@\n\x02p1\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_geometry_msgs.msg.line_segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LINESEGMENT']._serialized_start=218
  _globals['_LINESEGMENT']._serialized_end=421
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sensor_msgs/msg/battery_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/sensor_msgs/msg/battery_state.proto\x12*make87_messages_ros2.jazzy.sensor_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x9a\x03\n\x0c\x42\x61tteryState\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07voltage\x18\x02 \x01(\x02\x12\x13\n\x0btemperature\x18\x03 \x01(\x02\x12\x0f\n\x07\x63urrent\x18\x04 \x01(\x02\x12\x0e\n\x06\x63harge\x18\x05 \x01(\x02\x12\x10\n\x08\x63\x61pacity\x18\x06 \x01(\x02\x12\x17\n\x0f\x64\x65sign_capacity\x18\x07 \x01(\x02\x12\x12\n\npercentage\x18\x08 \x01(\x02\x12\x1b\n\x13power_supply_status\x18\t \x01(\r\x12\x1b\n\x13power_supply_health\x18\n \x01(\r\x12\x1f\n\x17power_supply_technology\x18\x0b \x01(\r\x12\x0f\n\x07present\x18\x0c \x01(\x08\x12\x14\n\x0c\x63\x65ll_voltage\x18\r \x03(\x02\x12\x18\n\x10\x63\x65ll_temperature\x18\x0e \x03(\x02\x12\x10\n\x08location\x18\x0f \x01(\t\x12\x15\n\rserial_number\x18\x10 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sensor_msgs.msg.battery_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BATTERYSTATE']._serialized_start=165
  _globals['_BATTERYSTATE']._serialized_end=575
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_feedback.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_feedback.proto\x12\x33make87_messages_ros2.rolling.visualization_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf2\x02\n\x19InteractiveMarkerFeedback\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x13\n\x0bmarker_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontrol_name\x18\x04 \x01(\t\x12\x12\n\nevent_type\x18\x05 \x01(\r\x12\x42\n\x04pose\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x15\n\rmenu_entry_id\x18\x07 \x01(\r\x12J\n\x0bmouse_point\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x19\n\x11mouse_point_valid\x18\t \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.visualization_msgs.msg.interactive_marker_feedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERFEEDBACK']._serialized_start=318
  _globals['_INTERACTIVEMARKERFEEDBACK']._serialized_end=688
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/msg/action_execution_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/plansys2_msgs/msg/action_execution_info.proto\x12-make87_messages_ros2.humble.plansys2_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\"\xab\x03\n\x13\x41\x63tionExecutionInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12M\n\x0bstart_stamp\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12N\n\x0cstatus_stamp\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x18\n\x10\x61\x63tion_full_name\x18\x05 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x06 \x01(\t\x12\x11\n\targuments\x18\x07 \x03(\t\x12N\n\x08\x64uration\x18\x08 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x12\n\ncompletion\x18\t \x01(\x02\x12\x16\n\x0emessage_status\x18\n \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.msg.action_execution_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIONEXECUTIONINFO']._serialized_start=290
  _globals['_ACTIONEXECUTIONINFO']._serialized_end=717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import transform_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_transform__stamped__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import allowed_collision_matrix_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_allowed__collision__matrix__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_padding_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_link__padding__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_scale_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_link__scale__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import object_color_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_object__color__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_world_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__world__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x46make87_messages_ros2/rolling/geometry_msgs/msg/transform_stamped.proto\x1aKmake87_messages_ros2/rolling/moveit_msgs/msg/allowed_collision_matrix.proto\x1a?make87_messages_ros2/rolling/moveit_msgs/msg/link_padding.proto\x1a=make87_messages_ros2/rolling/moveit_msgs/msg/link_scale.proto\x1a?make87_messages_ros2/rolling/moveit_msgs/msg/object_color.proto\x1aGmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto\x1a>make87_messages_ros2/rolling/moveit_msgs/msg/robot_state.proto\"\xa2\x05\n\rPlanningScene\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x0brobot_state\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.moveit_msgs.msg.RobotState\x12\x18\n\x10robot_model_name\x18\x03 \x01(\t\x12`\n\x16\x66ixed_frame_transforms\x18\x04 \x03(\x0b\x32@.make87_messages_ros2.rolling.geometry_msgs.msg.TransformStamped\x12\x66\n\x18\x61llowed_collision_matrix\x18\x05 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.moveit_msgs.msg.AllowedCollisionMatrix\x12O\n\x0clink_padding\x18\x06 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.moveit_msgs.msg.LinkPadding\x12K\n\nlink_scale\x18\x07 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.moveit_msgs.msg.LinkScale\x12P\n\robject_colors\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.moveit_msgs.msg.ObjectColor\x12O\n\x05world\x18\t \x01(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneWorld\x12\x0f\n\x07is_diff\x18\n \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENE']._serialized_start=595
  _globals['_PLANNINGSCENE']._serialized_end=1269
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.mavros_msgs.msg import file_entry_pb2 as _file_entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileListRequest(_message.Message):
    __slots__ = ["dir_path"]
    DIR_PATH_FIELD_NUMBER: _ClassVar[int]
    dir_path: str
    def __init__(self, dir_path: _Optional[str] = ...) -> None: ...

class FileListResponse(_message.Message):
    __slots__ = ["list", "success", "r_errno"]
    LIST_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    R_ERRNO_FIELD_NUMBER: _ClassVar[int]
    list: _containers.RepeatedCompositeFieldContainer[_file_entry_pb2.FileEntry]
    success: bool
    r_errno: int
    def __init__(self, list: _Optional[_Iterable[_Union[_file_entry_pb2.FileEntry, _Mapping]]] = ..., success: bool = ..., r_errno: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DqnRequest(_message.Message):
    __slots__ = ["action", "init"]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    INIT_FIELD_NUMBER: _ClassVar[int]
    action: int
    init: bool
    def __init__(self, action: _Optional[int] = ..., init: bool = ...) -> None: ...

class DqnResponse(_message.Message):
    __slots__ = ["state", "reward", "done"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    DONE_FIELD_NUMBER: _ClassVar[int]
    state: _containers.RepeatedScalarFieldContainer[float]
    reward: float
    done: bool
    def __init__(self, state: _Optional[_Iterable[float]] = ..., reward: _Optional[float] = ..., done: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/find_object_2d/msg/detection_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import float32_multi_array_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_float32__multi__array__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import int32_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_int32__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import string_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_string__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/find_object_2d/msg/detection_info.proto\x12-make87_messages_ros2.jazzy.find_object_2d.msg\x1a\x41make87_messages_ros2/jazzy/std_msgs/msg/float32_multi_array.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/int32.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/string.proto\"\xa8\x04\n\rDetectionInfo\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12;\n\x03ids\x18\x02 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12>\n\x06widths\x18\x03 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12?\n\x07heights\x18\x04 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12\x43\n\nfile_paths\x18\x05 \x03(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12?\n\x07inliers\x18\x06 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12@\n\x08outliers\x18\x07 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12P\n\x0chomographies\x18\x08 \x03(\x0b\x32:.make87_messages_ros2.jazzy.std_msgs.msg.Float32MultiArrayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.find_object_2d.msg.detection_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DETECTIONINFO']._serialized_start=346
  _globals['_DETECTIONINFO']._serialized_end=898
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import start_time_range_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_start__time__range__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1aLmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/start_time_range.proto\"\xfe\x01\n\x1a\x46lexibleTimeReservationAlt\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x01\x12Y\n\nstart_time\x18\x03 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.StartTimeRange\x12\x0f\n\x07has_end\x18\x04 \x01(\x08\x12O\n\x08\x64uration\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.flexible_time_reservation_alt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLEXIBLETIMERESERVATIONALT']._serialized_start=295
  _globals['_FLEXIBLETIMERESERVATIONALT']._serialized_end=549
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficLightElement(_message.Message):
    __slots__ = ["color", "shape", "status", "confidence"]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    color: int
    shape: int
    status: int
    confidence: float
    def __init__(self, color: _Optional[int] = ..., shape: _Optional[int] = ..., status: _Optional[int] = ..., confidence: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/webots_ros2_msgs/srv/spawn_urdf_robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.webots_ros2_msgs.msg import urdf_robot_pb2 as make87__messages__ros2_dot_humble_dot_webots__ros2__msgs_dot_msg_dot_urdf__robot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/webots_ros2_msgs/srv/spawn_urdf_robot.proto\x12\x30make87_messages_ros2.humble.webots_ros2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/webots_ros2_msgs/msg/urdf_robot.proto\"\x91\x01\n\x15SpawnUrdfRobotRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12J\n\x05robot\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.humble.webots_ros2_msgs.msg.UrdfRobot\"W\n\x16SpawnUrdfRobotResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.webots_ros2_msgs.srv.spawn_urdf_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPAWNURDFROBOTREQUEST']._serialized_start=228
  _globals['_SPAWNURDFROBOTREQUEST']._serialized_end=373
  _globals['_SPAWNURDFROBOTRESPONSE']._serialized_start=375
  _globals['_SPAWNURDFROBOTRESPONSE']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/soccer_geometry_msgs/msg/point_with_covariance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/soccer_geometry_msgs/msg/point_with_covariance.proto\x12\x33make87_messages_ros2.jazzy.soccer_geometry_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\"m\n\x13PointWithCovariance\x12\x42\n\x05point\x18\x01 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x12\n\ncovariance\x18\x02 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.soccer_geometry_msgs.msg.point_with_covariance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POINTWITHCOVARIANCE']._serialized_start=194
  _globals['_POINTWITHCOVARIANCE']._serialized_end=303
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_pb2 as _geographic_map_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeographicMapChanges(_message.Message):
    __slots__ = ["header", "diffs", "deletes"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DIFFS_FIELD_NUMBER: _ClassVar[int]
    DELETES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    diffs: _geographic_map_pb2.GeographicMap
    deletes: _containers.RepeatedCompositeFieldContainer[_uuid_pb2.UUID]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., diffs: _Optional[_Union[_geographic_map_pb2.GeographicMap, _Mapping]] = ..., deletes: _Optional[_Iterable[_Union[_uuid_pb2.UUID, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Mouse(_message.Message):
    __slots__ = ["header", "integrated_x", "integrated_y", "frame_id", "last_squal"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INTEGRATED_X_FIELD_NUMBER: _ClassVar[int]
    INTEGRATED_Y_FIELD_NUMBER: _ClassVar[int]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_SQUAL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    integrated_x: float
    integrated_y: float
    frame_id: int
    last_squal: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., integrated_x: _Optional[float] = ..., integrated_y: _Optional[float] = ..., frame_id: _Optional[int] = ..., last_squal: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.rcl_interfaces.msg import list_parameters_result_pb2 as _list_parameters_result_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListParametersRequest(_message.Message):
    __slots__ = ["prefixes", "depth"]
    PREFIXES_FIELD_NUMBER: _ClassVar[int]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    prefixes: _containers.RepeatedScalarFieldContainer[str]
    depth: int
    def __init__(self, prefixes: _Optional[_Iterable[str]] = ..., depth: _Optional[int] = ...) -> None: ...

class ListParametersResponse(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: _list_parameters_result_pb2.ListParametersResult
    def __init__(self, result: _Optional[_Union[_list_parameters_result_pb2.ListParametersResult, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/publisher_details.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/publisher_details.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg\"M\n\x10PublisherDetails\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x14\n\x0cmessage_type\x18\x02 \x01(\t\x12\x0f\n\x07latched\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.publisher_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PUBLISHERDETAILS']._serialized_start=138
  _globals['_PUBLISHERDETAILS']._serialized_end=215
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rviz_2d_overlay_msgs/msg/overlay_text.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rviz_2d_overlay_msgs/msg/overlay_text.proto\x12\x33make87_messages_ros2.jazzy.rviz_2d_overlay_msgs.msg\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\"\xfd\x02\n\x0bOverlayText\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x1b\n\x13horizontal_distance\x18\x04 \x01(\x05\x12\x19\n\x11vertical_distance\x18\x05 \x01(\x05\x12\x1c\n\x14horizontal_alignment\x18\x06 \x01(\r\x12\x1a\n\x12vertical_alignment\x18\x07 \x01(\r\x12\x44\n\x08\x62g_color\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x12\n\nline_width\x18\t \x01(\x05\x12\x11\n\ttext_size\x18\n \x01(\x02\x12\x0c\n\x04\x66ont\x18\x0b \x01(\t\x12\x44\n\x08\x66g_color\x18\x0c \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x0c\n\x04text\x18\r \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rviz_2d_overlay_msgs.msg.overlay_text_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OVERLAYTEXT']._serialized_start=186
  _globals['_OVERLAYTEXT']._serialized_end=567
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ackermann_msgs/msg/ackermann_drive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ackermann_msgs/msg/ackermann_drive.proto\x12/make87_messages_ros2.rolling.ackermann_msgs.msg\"|\n\x0e\x41\x63kermannDrive\x12\x16\n\x0esteering_angle\x18\x01 \x01(\x02\x12\x1f\n\x17steering_angle_velocity\x18\x02 \x01(\x02\x12\r\n\x05speed\x18\x03 \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x02\x12\x0c\n\x04jerk\x18\x05 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ackermann_msgs.msg.ackermann_drive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACKERMANNDRIVE']._serialized_start=122
  _globals['_ACKERMANNDRIVE']._serialized_end=246
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import region_of_interest_pb2 as _region_of_interest_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraInfo(_message.Message):
    __slots__ = ["header", "ros2_header", "height", "width", "distortion_model", "d", "k", "r", "p", "binning_x", "binning_y", "roi"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    DISTORTION_MODEL_FIELD_NUMBER: _ClassVar[int]
    D_FIELD_NUMBER: _ClassVar[int]
    K_FIELD_NUMBER: _ClassVar[int]
    R_FIELD_NUMBER: _ClassVar[int]
    P_FIELD_NUMBER: _ClassVar[int]
    BINNING_X_FIELD_NUMBER: _ClassVar[int]
    BINNING_Y_FIELD_NUMBER: _ClassVar[int]
    ROI_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    height: int
    width: int
    distortion_model: str
    d: _containers.RepeatedScalarFieldContainer[float]
    k: _containers.RepeatedScalarFieldContainer[float]
    r: _containers.RepeatedScalarFieldContainer[float]
    p: _containers.RepeatedScalarFieldContainer[float]
    binning_x: int
    binning_y: int
    roi: _region_of_interest_pb2.RegionOfInterest
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., height: _Optional[int] = ..., width: _Optional[int] = ..., distortion_model: _Optional[str] = ..., d: _Optional[_Iterable[float]] = ..., k: _Optional[_Iterable[float]] = ..., r: _Optional[_Iterable[float]] = ..., p: _Optional[_Iterable[float]] = ..., binning_x: _Optional[int] = ..., binning_y: _Optional[int] = ..., roi: _Optional[_Union[_region_of_interest_pb2.RegionOfInterest, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/display_robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import object_color_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_object__color__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/moveit_msgs/msg/display_robot_state.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/object_color.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\"\xba\x01\n\x11\x44isplayRobotState\x12\x45\n\x05state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12P\n\x0fhighlight_links\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.ObjectColor\x12\x0c\n\x04hide\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.display_robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPLAYROBOTSTATE']._serialized_start=242
  _globals['_DISPLAYROBOTSTATE']._serialized_end=428
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.ublox_msgs.msg import mon_ver_extension_pb2 as _mon_ver_extension_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MonVER(_message.Message):
    __slots__ = ["sw_version", "hw_version", "extension"]
    SW_VERSION_FIELD_NUMBER: _ClassVar[int]
    HW_VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    sw_version: _containers.RepeatedScalarFieldContainer[int]
    hw_version: _containers.RepeatedScalarFieldContainer[int]
    extension: _containers.RepeatedCompositeFieldContainer[_mon_ver_extension_pb2.MonVERExtension]
    def __init__(self, sw_version: _Optional[_Iterable[int]] = ..., hw_version: _Optional[_Iterable[int]] = ..., extension: _Optional[_Iterable[_Union[_mon_ver_extension_pb2.MonVERExtension, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.vision_msgs.msg import vision_class_pb2 as _vision_class_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LabelInfo(_message.Message):
    __slots__ = ["header", "class_map", "threshold"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CLASS_MAP_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    class_map: _containers.RepeatedCompositeFieldContainer[_vision_class_pb2.VisionClass]
    threshold: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., class_map: _Optional[_Iterable[_Union[_vision_class_pb2.VisionClass, _Mapping]]] = ..., threshold: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Leds(_message.Message):
    __slots__ = ["led0", "led1", "led2", "led3"]
    LED0_FIELD_NUMBER: _ClassVar[int]
    LED1_FIELD_NUMBER: _ClassVar[int]
    LED2_FIELD_NUMBER: _ClassVar[int]
    LED3_FIELD_NUMBER: _ClassVar[int]
    led0: bool
    led1: bool
    led2: bool
    led3: bool
    def __init__(self, led0: bool = ..., led1: bool = ..., led2: bool = ..., led3: bool = ...) -> None: ...



from make87_messages_ros2.rolling.apriltag_msgs.msg import point_pb2 as _point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AprilTagDetection(_message.Message):
    __slots__ = ["family", "id", "hamming", "goodness", "decision_margin", "centre", "corners", "homography"]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    HAMMING_FIELD_NUMBER: _ClassVar[int]
    GOODNESS_FIELD_NUMBER: _ClassVar[int]
    DECISION_MARGIN_FIELD_NUMBER: _ClassVar[int]
    CENTRE_FIELD_NUMBER: _ClassVar[int]
    CORNERS_FIELD_NUMBER: _ClassVar[int]
    HOMOGRAPHY_FIELD_NUMBER: _ClassVar[int]
    family: str
    id: int
    hamming: int
    goodness: float
    decision_margin: float
    centre: _point_pb2.Point
    corners: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    homography: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, family: _Optional[str] = ..., id: _Optional[int] = ..., hamming: _Optional[int] = ..., goodness: _Optional[float] = ..., decision_margin: _Optional[float] = ..., centre: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., corners: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., homography: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/camera_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import mounting_position_f_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_mounting__position__f__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/ibeo_msgs/msg/camera_image.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x44make87_messages_ros2/rolling/ibeo_msgs/msg/mounting_position_f.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa9\x04\n\x0b\x43\x61meraImage\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x14\n\x0cimage_format\x18\x03 \x01(\r\x12\x19\n\x11us_since_power_on\x18\x04 \x01(\r\x12L\n\ttimestamp\x18\x05 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x11\n\tdevice_id\x18\x06 \x01(\r\x12X\n\x11mounting_position\x18\x07 \x01(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.MountingPositionF\x12 \n\x18horizontal_opening_angle\x18\x08 \x01(\x01\x12\x1e\n\x16vertical_opening_angle\x18\t \x01(\x01\x12\x13\n\x0bimage_width\x18\n \x01(\r\x12\x14\n\x0cimage_height\x18\x0b \x01(\r\x12\x17\n\x0f\x63ompressed_size\x18\x0c \x01(\r\x12\x14\n\x0cimage_buffer\x18\r \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.camera_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CAMERAIMAGE']._serialized_start=367
  _globals['_CAMERAIMAGE']._serialized_end=920
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AftermarketLane(_message.Message):
    __slots__ = ["header", "ros2_header", "lane_confidence_left", "ldw_available_left", "lane_type_left", "distance_to_left_lane", "lane_confidence_right", "ldw_available_right", "lane_type_right", "distance_to_right_lane"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    LANE_CONFIDENCE_LEFT_FIELD_NUMBER: _ClassVar[int]
    LDW_AVAILABLE_LEFT_FIELD_NUMBER: _ClassVar[int]
    LANE_TYPE_LEFT_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_TO_LEFT_LANE_FIELD_NUMBER: _ClassVar[int]
    LANE_CONFIDENCE_RIGHT_FIELD_NUMBER: _ClassVar[int]
    LDW_AVAILABLE_RIGHT_FIELD_NUMBER: _ClassVar[int]
    LANE_TYPE_RIGHT_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_TO_RIGHT_LANE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    lane_confidence_left: int
    ldw_available_left: bool
    lane_type_left: int
    distance_to_left_lane: float
    lane_confidence_right: int
    ldw_available_right: bool
    lane_type_right: int
    distance_to_right_lane: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., lane_confidence_left: _Optional[int] = ..., ldw_available_left: bool = ..., lane_type_left: _Optional[int] = ..., distance_to_left_lane: _Optional[float] = ..., lane_confidence_right: _Optional[int] = ..., ldw_available_right: bool = ..., lane_type_right: _Optional[int] = ..., distance_to_right_lane: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ESFSensorStatus(_message.Message):
    __slots__ = ["header", "sensor_data_type", "used", "ready", "calib_status", "time_status", "freq", "fault_bad_meas", "fault_bad_ttag", "fault_missing_meas", "fault_noisy_meas"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SENSOR_DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    USED_FIELD_NUMBER: _ClassVar[int]
    READY_FIELD_NUMBER: _ClassVar[int]
    CALIB_STATUS_FIELD_NUMBER: _ClassVar[int]
    TIME_STATUS_FIELD_NUMBER: _ClassVar[int]
    FREQ_FIELD_NUMBER: _ClassVar[int]
    FAULT_BAD_MEAS_FIELD_NUMBER: _ClassVar[int]
    FAULT_BAD_TTAG_FIELD_NUMBER: _ClassVar[int]
    FAULT_MISSING_MEAS_FIELD_NUMBER: _ClassVar[int]
    FAULT_NOISY_MEAS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sensor_data_type: int
    used: bool
    ready: bool
    calib_status: int
    time_status: int
    freq: int
    fault_bad_meas: bool
    fault_bad_ttag: bool
    fault_missing_meas: bool
    fault_noisy_meas: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sensor_data_type: _Optional[int] = ..., used: bool = ..., ready: bool = ..., calib_status: _Optional[int] = ..., time_status: _Optional[int] = ..., freq: _Optional[int] = ..., fault_bad_meas: bool = ..., fault_bad_ttag: bool = ..., fault_missing_meas: bool = ..., fault_noisy_meas: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import detected_tag_pb2 as _detected_tag_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import tag_pb2 as _tag_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectTagsRequest(_message.Message):
    __slots__ = ["tags", "pose_frame", "robot_pose"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[_tag_pb2.Tag]
    pose_frame: str
    robot_pose: _pose_pb2.Pose
    def __init__(self, tags: _Optional[_Iterable[_Union[_tag_pb2.Tag, _Mapping]]] = ..., pose_frame: _Optional[str] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class DetectTagsResponse(_message.Message):
    __slots__ = ["tags", "timestamp", "return_code"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[_detected_tag_pb2.DetectedTag]
    timestamp: _time_pb2.Time
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, tags: _Optional[_Iterable[_Union[_detected_tag_pb2.DetectedTag, _Mapping]]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CloseBlackboardStreamRequest(_message.Message):
    __slots__ = ["topic_name"]
    TOPIC_NAME_FIELD_NUMBER: _ClassVar[int]
    topic_name: str
    def __init__(self, topic_name: _Optional[str] = ...) -> None: ...

class CloseBlackboardStreamResponse(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: bool
    def __init__(self, result: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/file_remove.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/srv/file_remove.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"&\n\x11\x46ileRemoveRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\"6\n\x12\x46ileRemoveResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07r_errno\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.file_remove_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FILEREMOVEREQUEST']._serialized_start=108
  _globals['_FILEREMOVEREQUEST']._serialized_end=146
  _globals['_FILEREMOVERESPONSE']._serialized_start=148
  _globals['_FILEREMOVERESPONSE']._serialized_end=202
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import location_pb2 as _location_pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import robot_mode_pb2 as _robot_mode_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RobotState(_message.Message):
    __slots__ = ["name", "model", "task_id", "seq", "mode", "battery_percent", "location", "path"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    SEQ_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    BATTERY_PERCENT_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    name: str
    model: str
    task_id: str
    seq: int
    mode: _robot_mode_pb2.RobotMode
    battery_percent: float
    location: _location_pb2.Location
    path: _containers.RepeatedCompositeFieldContainer[_location_pb2.Location]
    def __init__(self, name: _Optional[str] = ..., model: _Optional[str] = ..., task_id: _Optional[str] = ..., seq: _Optional[int] = ..., mode: _Optional[_Union[_robot_mode_pb2.RobotMode, _Mapping]] = ..., battery_percent: _Optional[float] = ..., location: _Optional[_Union[_location_pb2.Location, _Mapping]] = ..., path: _Optional[_Iterable[_Union[_location_pb2.Location, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgVALGET(_message.Message):
    __slots__ = ["version", "layers", "position", "keys"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    LAYERS_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    version: int
    layers: int
    position: int
    keys: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, version: _Optional[int] = ..., layers: _Optional[int] = ..., position: _Optional[int] = ..., keys: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/type_description_interfaces/msg/type_description.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.type_description_interfaces.msg import individual_type_description_pb2 as make87__messages__ros2_dot_rolling_dot_type__description__interfaces_dot_msg_dot_individual__type__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/type_description_interfaces/msg/type_description.proto\x12<make87_messages_ros2.rolling.type_description_interfaces.msg\x1a^make87_messages_ros2/rolling/type_description_interfaces/msg/individual_type_description.proto\"\x83\x02\n\x0fTypeDescription\x12q\n\x10type_description\x18\x01 \x01(\x0b\x32W.make87_messages_ros2.rolling.type_description_interfaces.msg.IndividualTypeDescription\x12}\n\x1creferenced_type_descriptions\x18\x02 \x03(\x0b\x32W.make87_messages_ros2.rolling.type_description_interfaces.msg.IndividualTypeDescriptionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.type_description_interfaces.msg.type_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TYPEDESCRIPTION']._serialized_start=246
  _globals['_TYPEDESCRIPTION']._serialized_end=505
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as _move_it_error_codes_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetGroupUrdfRequest(_message.Message):
    __slots__ = ["header", "group_name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    group_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., group_name: _Optional[str] = ...) -> None: ...

class GetGroupUrdfResponse(_message.Message):
    __slots__ = ["header", "error_code", "urdf_string"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    URDF_STRING_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    error_code: _move_it_error_codes_pb2.MoveItErrorCodes
    urdf_string: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., error_code: _Optional[_Union[_move_it_error_codes_pb2.MoveItErrorCodes, _Mapping]] = ..., urdf_string: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import itinerary_pb2 as _itinerary_pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import negotiation_key_pb2 as _negotiation_key_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationRejection(_message.Message):
    __slots__ = ["conflict_version", "table", "rejected_by", "alternatives"]
    CONFLICT_VERSION_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    REJECTED_BY_FIELD_NUMBER: _ClassVar[int]
    ALTERNATIVES_FIELD_NUMBER: _ClassVar[int]
    conflict_version: int
    table: _containers.RepeatedCompositeFieldContainer[_negotiation_key_pb2.NegotiationKey]
    rejected_by: int
    alternatives: _containers.RepeatedCompositeFieldContainer[_itinerary_pb2.Itinerary]
    def __init__(self, conflict_version: _Optional[int] = ..., table: _Optional[_Iterable[_Union[_negotiation_key_pb2.NegotiationKey, _Mapping]]] = ..., rejected_by: _Optional[int] = ..., alternatives: _Optional[_Iterable[_Union[_itinerary_pb2.Itinerary, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispenserState(_message.Message):
    __slots__ = ["header", "time", "guid", "mode", "request_guid_queue", "seconds_remaining"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    GUID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_GUID_QUEUE_FIELD_NUMBER: _ClassVar[int]
    SECONDS_REMAINING_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time: _time_pb2.Time
    guid: str
    mode: int
    request_guid_queue: _containers.RepeatedScalarFieldContainer[str]
    seconds_remaining: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., guid: _Optional[str] = ..., mode: _Optional[int] = ..., request_guid_queue: _Optional[_Iterable[str]] = ..., seconds_remaining: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ESFMeasDataItem(_message.Message):
    __slots__ = ["data_field", "data_type"]
    DATA_FIELD_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    data_field: int
    data_type: int
    def __init__(self, data_field: _Optional[int] = ..., data_type: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/wiimote_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.humble.wiimote_msgs.msg import ir_source_info_pb2 as make87__messages__ros2_dot_humble_dot_wiimote__msgs_dot_msg_dot_ir__source__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/wiimote_msgs/msg/state.proto\x12,make87_messages_ros2.humble.wiimote_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\x1a\x41make87_messages_ros2/humble/wiimote_msgs/msg/ir_source_info.proto\"\xca\x08\n\x05State\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12W\n\x17\x61ngular_velocity_zeroed\x18\x03 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12T\n\x14\x61ngular_velocity_raw\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12#\n\x1b\x61ngular_velocity_covariance\x18\x05 \x03(\x01\x12Z\n\x1alinear_acceleration_zeroed\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12W\n\x17linear_acceleration_raw\x18\x07 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12&\n\x1elinear_acceleration_covariance\x18\x08 \x03(\x01\x12[\n\x1bnunchuk_acceleration_zeroed\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12X\n\x18nunchuk_acceleration_raw\x18\n \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x1f\n\x17nunchuk_joystick_zeroed\x18\x0b \x03(\x02\x12\x1c\n\x14nunchuk_joystick_raw\x18\x0c \x03(\x02\x12\x0f\n\x07\x62uttons\x18\r \x03(\x08\x12\x17\n\x0fnunchuk_buttons\x18\x0e \x03(\x08\x12\x0c\n\x04leds\x18\x0f \x03(\x08\x12\x0e\n\x06rumble\x18\x10 \x01(\x08\x12O\n\x0bir_tracking\x18\x11 \x03(\x0b\x32:.make87_messages_ros2.humble.wiimote_msgs.msg.IrSourceInfo\x12\x13\n\x0braw_battery\x18\x12 \x01(\x02\x12\x17\n\x0fpercent_battery\x18\x13 \x01(\x02\x12N\n\x0czeroing_time\x18\x14 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x0e\n\x06\x65rrors\x18\x15 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.wiimote_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=388
  _globals['_STATE']._serialized_end=1486
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/image_marker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/visualization_msgs/msg/image_marker.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xdd\x04\n\x0bImageMarker\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x05\x12\x45\n\x08position\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\r\n\x05scale\x18\x07 \x01(\x02\x12I\n\routline_color\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x0e\n\x06\x66illed\x18\t \x01(\r\x12\x46\n\nfill_color\x18\n \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12M\n\x08lifetime\x18\x0b \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x43\n\x06points\x18\x0c \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12J\n\x0eoutline_colors\x18\r \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.image_marker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IMAGEMARKER']._serialized_start=360
  _globals['_IMAGEMARKER']._serialized_end=965
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/vision.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import ball_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_ball__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import field_line_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_field__line__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import flag_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_flag__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import goalpost_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_goalpost__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import player_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_player__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/vision.proto\x12\x30make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg\x1a;make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/ball.proto\x1a\x41make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/field_line.proto\x1a;make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/flag.proto\x1a?make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto\x1a=make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/player.proto\"\x81\x03\n\x06Vision\x12\x44\n\x04\x62\x61ll\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Ball\x12P\n\x0b\x66ield_lines\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.FieldLine\x12\x45\n\x05\x66lags\x18\x03 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Flag\x12M\n\tgoalposts\x18\x04 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Goalpost\x12I\n\x07players\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Playerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.vision_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VISION']._serialized_start=433
  _globals['_VISION']._serialized_end=818
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SaveGridRequest(_message.Message):
    __slots__ = ["header", "file_name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    file_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., file_name: _Optional[str] = ...) -> None: ...

class SaveGridResponse(_message.Message):
    __slots__ = ["header", "map_size_bytes", "status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map_size_bytes: float
    status: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map_size_bytes: _Optional[float] = ..., status: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TrackstatChannel(_message.Message):
    __slots__ = ["prn", "glofreq", "ch_tr_status", "psr", "doppler", "c_no", "locktime", "psr_res", "reject", "psr_weight"]
    PRN_FIELD_NUMBER: _ClassVar[int]
    GLOFREQ_FIELD_NUMBER: _ClassVar[int]
    CH_TR_STATUS_FIELD_NUMBER: _ClassVar[int]
    PSR_FIELD_NUMBER: _ClassVar[int]
    DOPPLER_FIELD_NUMBER: _ClassVar[int]
    C_NO_FIELD_NUMBER: _ClassVar[int]
    LOCKTIME_FIELD_NUMBER: _ClassVar[int]
    PSR_RES_FIELD_NUMBER: _ClassVar[int]
    REJECT_FIELD_NUMBER: _ClassVar[int]
    PSR_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    prn: int
    glofreq: int
    ch_tr_status: int
    psr: float
    doppler: float
    c_no: float
    locktime: float
    psr_res: float
    reject: str
    psr_weight: float
    def __init__(self, prn: _Optional[int] = ..., glofreq: _Optional[int] = ..., ch_tr_status: _Optional[int] = ..., psr: _Optional[float] = ..., doppler: _Optional[float] = ..., c_no: _Optional[float] = ..., locktime: _Optional[float] = ..., psr_res: _Optional[float] = ..., reject: _Optional[str] = ..., psr_weight: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.ibeo_msgs.msg import tracked_properties_pb2 as _tracked_properties_pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import untracked_properties_pb2 as _untracked_properties_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Object2271(_message.Message):
    __slots__ = ["id", "tracked_properties_available", "untracked_properties_available", "tracked_properties", "untracked_properties"]
    ID_FIELD_NUMBER: _ClassVar[int]
    TRACKED_PROPERTIES_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    UNTRACKED_PROPERTIES_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    TRACKED_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    UNTRACKED_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    id: int
    tracked_properties_available: bool
    untracked_properties_available: bool
    tracked_properties: _tracked_properties_pb2.TrackedProperties
    untracked_properties: _untracked_properties_pb2.UntrackedProperties
    def __init__(self, id: _Optional[int] = ..., tracked_properties_available: bool = ..., untracked_properties_available: bool = ..., tracked_properties: _Optional[_Union[_tracked_properties_pb2.TrackedProperties, _Mapping]] = ..., untracked_properties: _Optional[_Union[_untracked_properties_pb2.UntrackedProperties, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SBASService(_message.Message):
    __slots__ = ["header", "ranging", "corrections", "integrity", "test_mode", "bad"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RANGING_FIELD_NUMBER: _ClassVar[int]
    CORRECTIONS_FIELD_NUMBER: _ClassVar[int]
    INTEGRITY_FIELD_NUMBER: _ClassVar[int]
    TEST_MODE_FIELD_NUMBER: _ClassVar[int]
    BAD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ranging: bool
    corrections: bool
    integrity: bool
    test_mode: bool
    bad: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ranging: bool = ..., corrections: bool = ..., integrity: bool = ..., test_mode: bool = ..., bad: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as _twist_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MultiDOFJointTrajectoryPoint(_message.Message):
    __slots__ = ["transforms", "velocities", "accelerations", "time_from_start"]
    TRANSFORMS_FIELD_NUMBER: _ClassVar[int]
    VELOCITIES_FIELD_NUMBER: _ClassVar[int]
    ACCELERATIONS_FIELD_NUMBER: _ClassVar[int]
    TIME_FROM_START_FIELD_NUMBER: _ClassVar[int]
    transforms: _containers.RepeatedCompositeFieldContainer[_transform_pb2.Transform]
    velocities: _containers.RepeatedCompositeFieldContainer[_twist_pb2.Twist]
    accelerations: _containers.RepeatedCompositeFieldContainer[_twist_pb2.Twist]
    time_from_start: _duration_pb2.Duration
    def __init__(self, transforms: _Optional[_Iterable[_Union[_transform_pb2.Transform, _Mapping]]] = ..., velocities: _Optional[_Iterable[_Union[_twist_pb2.Twist, _Mapping]]] = ..., accelerations: _Optional[_Iterable[_Union[_twist_pb2.Twist, _Mapping]]] = ..., time_from_start: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerSetAttitude(_message.Message):
    __slots__ = ["target_system", "target_component", "flags", "gimbal_device_id", "q", "angular_velocity_x", "angular_velocity_y", "angular_velocity_z"]
    TARGET_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TARGET_COMPONENT_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    Q_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_X_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_Y_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_Z_FIELD_NUMBER: _ClassVar[int]
    target_system: int
    target_component: int
    flags: int
    gimbal_device_id: int
    q: _quaternion_pb2.Quaternion
    angular_velocity_x: float
    angular_velocity_y: float
    angular_velocity_z: float
    def __init__(self, target_system: _Optional[int] = ..., target_component: _Optional[int] = ..., flags: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ..., q: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., angular_velocity_x: _Optional[float] = ..., angular_velocity_y: _Optional[float] = ..., angular_velocity_z: _Optional[float] = ...) -> None: ...
